
================
Next API changes
================

.. ifconfig:: releaselevel == 'dev'

   This page lists API changes for the next release.

   Behavior changes
   ----------------

   .. toctree::
      :glob:
      :maxdepth: 1

      next_api_changes/behavior/*

   Deprecations
   ------------

   .. toctree::
      :glob:
      :maxdepth: 1

      next_api_changes/deprecations/*

   Removals
   --------

   .. toctree::
      :glob:
      :maxdepth: 1

      next_api_changes/removals/*

   Development changes
   -------------------

   .. toctree::
      :glob:
      :maxdepth: 1

      next_api_changes/development/*
